#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_COMPARE_GREATER_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_COMPARE_GREATER_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/simd/compare_greater.hpp>

#endif
